<?php

class BinContact
{
	function __construct()
	{
		// translation
		add_action('init', [$this, 'load_textdomain']);
		
		// add styles/scripts
		add_action('admin_enqueue_scripts', [$this, 'admin_enqueue_scripts']);
		add_action('wp_enqueue_scripts', [$this, 'enqueue_scripts']);
		
		// dependency check
		add_action('wp_ajax_bin_contact_admin_notice_dismiss', [$this, 'wp_ajax_bin_contact_admin_notice_dismiss']);
		if(get_option('bin_contact_dependency_check') === 'enabled') { add_action('admin_notices', [$this, 'admin_notice']); }
	}
	
	/**
	 * load textdomain
	 */
	function load_textdomain()
	{
		// vars
		$domain = 'bin-contact';
		$locale = is_admin() && function_exists('get_user_locale') ? get_user_locale() : get_locale();
		$mofile = $domain.'-'.$locale.'.mo';

		// load from the languages directory first
		load_textdomain($domain, WP_LANG_DIR.'/plugins/'.$mofile);

		// redirect missing translations
		$mofile = str_replace('de_DE', 'de_CH', $mofile);

		// load from plugin lang folder
		$loaded = load_textdomain($domain, BIN_CONTACT_DIR.'/languages/'.$mofile);
	}
	
	/**
	 * Add admin style/script
	 */
	function admin_enqueue_scripts()
	{
		wp_enqueue_media();
		
		wp_enqueue_style('leafleft', BIN_CONTACT_URL.'/ext/leaflet/leaflet.css', false, '1.4.0');
		wp_enqueue_style('bin-contact-back', BIN_CONTACT_URL.'/css/back.css', ['wp-color-picker']);
		
		wp_enqueue_script('leafleft', BIN_CONTACT_URL.'/ext/leaflet/leaflet.js', false, '1.4.0', true);
		wp_register_script('bin-contact-back', BIN_CONTACT_URL.'/js/back.js', ['wp-color-picker'], BIN_CONTACT_VERSION, true);
		wp_localize_script('bin-contact-back', 'bin_contact_back', [
			'osm_tiles' => 'https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png',
			'osm_attribution' => '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors',
			'current' => __('This is currently set as location', 'bin-contact'),
			'update' => __('Set this location', 'bin-contact'),
			'sorry' => __('Sorry, no results...', 'bin-contact'),
		]);
		wp_enqueue_script('bin-contact-back');
	}
	
	/**
	 * Add frontend style/script
	 */
	function enqueue_scripts()
	{
		//wp_enqueue_style('leafleft', BIN_CONTACT_URL.'/ext/leaflet/leaflet.css', false, '1.4.0');
		wp_register_style('bin-contact-front', BIN_CONTACT_URL.'/css/front.css', false, BIN_CONTACT_VERSION);
		
		/*wp_enqueue_script('leafleft', BIN_CONTACT_URL.'/ext/leaflet/leaflet.js', false, '1.4.0', true);
		wp_register_script('bin-contact-front', BIN_CONTACT_URL.'/js/front.js', false, BIN_CONTACT_VERSION, true);
		wp_localize_script('bin-contact-front', 'bin_contact_front', [
			'osm_tiles' => 'https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png',
			'osm_attribution' => '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors',
			//'osm_tiles' => 'https://api.tiles.mapbox.com/v4/{id}/{z}/{x}/{y}.png?access_token=pk.eyJ1IjoibWFwYm94IiwiYSI6ImNpejY4NXVycTA2emYycXBndHRqcmZ3N3gifQ.rJcFIG214AriISLbB6B5aw'
		]);
		wp_enqueue_script('bin-contact-front');*/
	}
	
	/**
	 * Add dependency check message
	 */
	function admin_notice()
	{
		$checkPlugins = [
			'bin-spam-protection' => [
				'name' => 'Email Spam Protection',
				'path' => 'bin-email-spam-protection/bin-email-spam-protection.php',
				'text_activate' => __('The plugin <strong>%s</strong> is recommended to protect email addresses in frontend from collecting by spam bots.', 'bin-contact')
			]
		];

		$installedPlugins = get_plugins();

		$sitewidePlugins = [];
		if(is_array(get_site_option('active_sitewide_plugins'))) { $sitewidePlugins = get_site_option('active_sitewide_plugins'); }
		$plugins = array_merge(array_flip(get_option('active_plugins')), $sitewidePlugins);

		$message = '';
		foreach($checkPlugins as $checkPluginName => $checkPluginInfo)
		{
			if(!array_key_exists($checkPluginInfo['path'], $plugins))
			{
				if(isset($installedPlugins[$checkPluginInfo['path']]))
				{
					$message .= '<p>'.sprintf($checkPluginInfo['text_activate'], $checkPluginInfo['name']).' <a class="button" href="'.self_admin_url('plugins.php').'">'.__('Activate', 'bin-contact').'</a></p>';
				}
				else
				{
					$url = add_query_arg(['action' => 'install-plugin', 'plugin' => $checkPluginName], self_admin_url('update.php'));
					$message .= '<p>'.sprintf($checkPluginInfo['text_activate'], $checkPluginInfo['name']).' <a class="button" href="'.wp_nonce_url($url, 'install-plugin_'.$checkPluginName).'">'.__('Install', 'bin-contact').'</a></p>';
				}
			}
		}

		if(!empty($message))
		{
			echo '<div id="bin_contact_admin_notice" class="notice notice-error">';
				echo '<p><strong>'.sprintf(__('%s dependency check failed', 'bin-opt-in'), 'Bin Contact').'</strong></p>';
				echo '<div class="bin_contact_admin_notice_message">'.$message.'</div>';
				echo '<p><a href="admin.php?page=bin_contact_option_setting" class="bin_contact_admin_notice_dismiss">'.__('Disable notice', 'bin-contact').'</a></p>';
			echo '</div>';
		}
	}
	
	/**
	 * set dependency check disabled
	 */
	function wp_ajax_bin_contact_admin_notice_dismiss()
	{
		update_option('bin_contact_dependency_check', 'disabled');
		wp_die();
	}
	
	/*
	 * default options
	 */
	private static function options()
	{
		return [
			'bin_contact_dependency_check' => 'enabled',
		];
	}
	
	/**
	 * fires on activate plugin
	 * add initial options to settings page
	 * register schedule events
	 */
	public static function activate()
	{
		foreach(self::options() as $option => $value)
		{
			if(!get_option($option))
			{
				add_option($option, $value);
			}
		}
    }
	
	/**
	 * fires on deactivate plugin
	 * unregister schedule events
	 */
	public static function deactivate()
	{
		self::uninstall();
	}
	
	/**
	 * fires on uninstall plugin
	 * delete options
	 */
	public static function uninstall()
	{
		foreach(self::options() as $option => $value)
		{
			delete_option($option);
		}
	}
	
	/*
	 * parse list items
	 */
	static function parse_list($list)
	{
		$level_1 = [];
		if(!is_array($list)) {
			$level_1 = preg_split('/[,]+/', $list, -1, PREG_SPLIT_NO_EMPTY);
		}

		$level_2 = [];
		foreach($level_1 as $item)
		{
			$level_2[] = preg_split('/[:]+/', $item, -1, PREG_SPLIT_NO_EMPTY);
		}
		
		return $level_2;
	}
	
	/**
	 * return contacts
	 */
	static function get_contacts($atts)
	{
		$atts = shortcode_atts([
			'page' => isset($_GET['contact-page']) ? abs((int)$_GET['contact-page']) : 1,
			'posts_per_page' => 20,
			'group' => '',
			'order' => 'ASC',
			'orderby' => 'date',
			'post_status' => 'any'
		], $atts);
		
		$page = isset($_GET['contact-page']) ? abs((int)$_GET['contact-page']) : 1;
		$contacts = new WP_Query([
			'posts_per_page' => $atts['posts_per_page'],
			'tax_query' => $atts['group'] ? [['taxonomy' => 'contact_group', 'terms' => $atts['group'], 'field' => 'term_id']] : '',
			'paged' => $atts['page'],
			'post_type' => 'contact',
			'order' => $atts['order'],
			'orderby' => ($atts['orderby'] !== 'date' ? 'meta_value' : 'date'),
			'meta_key' => ($atts['orderby'] !== 'date' ? $atts['orderby'] : ''),
			'post_status' => $atts['post_status']
		]);
		
		return $contacts;
	}
	
	static function formTextLabels()
	{
		return [
			'image' => __('Image', 'bin-contact'),
			'company' => __('Company', 'bin-contact'),
			'salutation' => __('Salutation', 'bin-contact'),
			'name_suffix' => __('Name suffix', 'bin-contact'),
			'first_name' => __('First name', 'bin-contact'),	
			'last_name' => __('Last name', 'bin-contact'),
			'designation' => __('Designation', 'bin-contact'),
			'polite_form' => __('Polite form', 'bin-contact'),
			'language_of_correspondence' => __('Language of correspondence', 'bin-contact'),
			'email' => __('Email', 'bin-contact'),
			'email_link' => __('Email', 'bin-contact'),
			'email_button' => __('Email', 'bin-contact'),
			'email_status' => __('Email status', 'bin-contact'),
			'mobile' => __('Mobile', 'bin-contact'),
			'mobile_status' => __('Mobile status', 'bin-contact'),
			'phone_private' => __('Phone (private)', 'bin-contact'),
			'phone_work' => __('Phone (work)', 'bin-contact'),
			'additional_designation' => __('Additional designation', 'bin-contact'),
			'street_and_number' => __('Street and number', 'bin-contact'),
			'zip' => __('Zip', 'bin-contact'),
			'city' => __('City', 'bin-contact'),
			'country' => __('Country', 'bin-contact'),
			'marker_type' => __('Marker type', 'bin-contact'),
			'marker_custom' => __('Custom Image', 'bin-contact'),
			'marker_custom2x' => __('Custom Image (2x)', 'bin-contact'),
			'lat' => __('Latitude (lat)', 'bin-contact'),
			'lng' => __('Longitude (lng)', 'bin-contact'),
			'website' => __('Website', 'bin-contact'),
			'website_button' => __('Website', 'bin-contact'),
			'website_link' => __('Website', 'bin-contact'),
			'facebook' => __('Facebook', 'bin-contact'),
			'facebook_button' => __('Facebook', 'bin-contact'),
			'facebook_link' => __('Facebook', 'bin-contact'),
			'twitter' => __('Twitter', 'bin-contact'),
			'twitter_button' => __('Twitter', 'bin-contact'),
			'twitter_link' => __('Twitter', 'bin-contact'),
			'instagram' => __('Instagram', 'bin-contact'),
			'instagram_button' => __('Instagram', 'bin-contact'),
			'instagram_link' => __('Instagram', 'bin-contact'),
			'flickr' => __('Flickr', 'bin-contact'),
			'flickr_button' => __('Flickr', 'bin-contact'),
			'flickr_link' => __('Flickr', 'bin-contact'),
			'youtube' => __('Youtube', 'bin-contact'),
			'youtube_button' => __('Youtube', 'bin-contact'),
			'youtube_link' => __('Youtube', 'bin-contact'),
			'linkedin' => __('LinkedIn', 'bin-contact'),
			'linkedin_button' => __('LinkedIn', 'bin-contact'),
			'linkedin_link' => __('LinkedIn', 'bin-contact'),
			'xing' => __('Xing', 'bin-contact'),
			'xing_button' => __('Xing', 'bin-contact'),
			'xing_link' => __('Xing', 'bin-contact'),
			'socialmedia_other1' => __('Other (1)', 'bin-contact'),
			'socialmedia_other1_button' => __('Other (1)', 'bin-contact'),
			'socialmedia_other1_link' => __('Other (1)', 'bin-contact'),
			'socialmedia_other2' => __('Other (2)', 'bin-contact'),
			'socialmedia_other2_button' => __('Other (2)', 'bin-contact'),
			'socialmedia_other2_link' => __('Other (2)', 'bin-contact'),
			'socialmedia_other3' => __('Other (3)', 'bin-contact'),
			'socialmedia_other3_button' => __('Other (3)', 'bin-contact'),
			'socialmedia_other3_link' => __('Other (3)', 'bin-contact'),
			'website_and_socialmedia_buttons' => __('Website and social media', 'bin-contact'),
			'full_name' => __('Name', 'bin_contact'),
			'zip_and_city' => __('Zip and city', 'bin_contact'),
			'terms_and_conditions_accepted' => __('Terms and conditions accepted', 'bin_contact'),
			'privacy_policy_accepted' => __('Privacy Policy accepted', 'bin_contact'),
		];
	}
	
	static function formSalutation()
	{
		return [
			0 => __('Mrs', 'bin-contact'),
			1 => __('Mr', 'bin-contact'),
			2 => __('Other', 'bin-contact')
		];
	}
	
	static function formPoliteform()
	{
		return [
			0 => __('Personal', 'bin-contact'),
			1 => __('Formal', 'bin-contact')
		];
	}
	
	static function formLanguage()
	{
		return [
			0 => 'AF',
			1 => 'SQ',
			2 => 'AR',
			3 => 'HY',
			4 => 'EU',
			5 => 'BN',
			6 => 'BG',
			7 => 'CA',
			8 => 'KM',
			9 => 'ZH',
			10 => 'HR',
			11 => 'CS',
			12 => 'DA',
			13 => 'NL',
			14 => 'EN',
			15 => 'ET',
			16 => 'FJ',
			17 => 'FI',
			18 => 'FR',
			19 => 'KA',
			20 => 'DE',
			21 => 'EL',
			22 => 'GU',
			23 => 'HE',
			24 => 'HI',
			25 => 'HU',
			26 => 'IS',
			27 => 'ID',
			28 => 'GA',
			29 => 'IT',
			30 => 'JA',
			31 => 'JW',
			32 => 'KO',
			33 => 'LA',
			34 => 'LV',
			35 => 'LT',
			36 => 'MK',
			37 => 'MS',
			38 => 'ML',
			39 => 'MT',
			40 => 'MI',
			41 => 'MR',
			42 => 'MN',
			43 => 'NE',
			44 => 'NO',
			45 => 'FA',
			46 => 'PL',
			47 => 'PT',
			48 => 'PA',
			49 => 'QU',
			50 => 'RO',
			51 => 'RM',
			52 => 'RU',
			53 => 'SM',
			54 => 'SR',
			55 => 'SK',
			56 => 'SL',
			57 => 'ES',
			58 => 'SW',
			59 => 'SV',
			60 => 'TA',
			61 => 'IT',
			62 => 'TE',
			63 => 'TH',
			64 => 'BO',
			65 => 'TO',
			66 => 'TR',
			67 => 'UK',
			68 => 'UR',
			69 => 'UZ',
			70 => 'VI',
			71 => 'CY',
			72 => 'XH',
		];
	}
	
	static function formLanguageValue()
	{
		return [
			'AF' => __('Afrikanns', 'bin-contact'),
			'SQ' => __('Albanian', 'bin-contact'),
			'AR' => __('Arabic', 'bin-contact'),
			'HY' => __('Armenian', 'bin-contact'),
			'EU' => __('Basque', 'bin-contact'),
			'BN' => __('Bengali', 'bin-contact'),
			'BG' => __('Bulgarian', 'bin-contact'),
			'CA' => __('Catalan', 'bin-contact'),
			'KM' => __('Cambodian', 'bin-contact'),
			'ZH' => __('Chinese (Mandarin)', 'bin-contact'),
			'HR' => __('Croation', 'bin-contact'),
			'CS' => __('Czech', 'bin-contact'),
			'DA' => __('Danish', 'bin-contact'),
			'NL' => __('Dutch', 'bin-contact'),
			'EN' => __('English', 'bin-contact'),
			'ET' => __('Estonian', 'bin-contact'),
			'FJ' => __('Fiji', 'bin-contact'),
			'FI' => __('Finnish', 'bin-contact'),
			'FR' => __('French', 'bin-contact'),
			'KA' => __('Georgian', 'bin-contact'),
			'DE' => __('German', 'bin-contact'),
			'EL' => __('Greek', 'bin-contact'),
			'GU' => __('Gujarati', 'bin-contact'),
			'HE' => __('Hebrew', 'bin-contact'),
			'HI' => __('Hindi', 'bin-contact'),
			'HU' => __('Hungarian', 'bin-contact'),
			'IS' => __('Icelandic', 'bin-contact'),
			'ID' => __('Indonesian', 'bin-contact'),
			'GA' => __('Irish', 'bin-contact'),
			'IT' => __('Italian', 'bin-contact'),
			'JA' => __('Japanese', 'bin-contact'),
			'JW' => __('Javanese', 'bin-contact'),
			'KO' => __('Korean', 'bin-contact'),
			'LA' => __('Latin', 'bin-contact'),
			'LV' => __('Latvian', 'bin-contact'),
			'LT' => __('Lithuanian', 'bin-contact'),
			'MK' => __('Macedonian', 'bin-contact'),
			'MS' => __('Malay', 'bin-contact'),
			'ML' => __('Malayalam', 'bin-contact'),
			'MT' => __('Maltese', 'bin-contact'),
			'MI' => __('Maori', 'bin-contact'),
			'MR' => __('Marathi', 'bin-contact'),
			'MN' => __('Mongolian', 'bin-contact'),
			'NE' => __('Nepali', 'bin-contact'),
			'NO' => __('Norwegian', 'bin-contact'),
			'FA' => __('Persian', 'bin-contact'),
			'PL' => __('Polish', 'bin-contact'),
			'PT' => __('Portuguese', 'bin-contact'),
			'PA' => __('Punjabi', 'bin-contact'),
			'QU' => __('Quechua', 'bin-contact'),
			'RO' => __('Romanian', 'bin-contact'),
			'RM' => __('Rumantsch', 'bin-contact'),
			'RU' => __('Russian', 'bin-contact'),
			'SM' => __('Samoan', 'bin-contact'),
			'SR' => __('Serbian', 'bin-contact'),
			'SK' => __('Slovak', 'bin-contact'),
			'SL' => __('Slovenian', 'bin-contact'),
			'ES' => __('Spanish', 'bin-contact'),
			'SW' => __('Swahili', 'bin-contact'),
			'SV' => __('Swedish', 'bin-contact'),
			'TA' => __('Tamil', 'bin-contact'),
			'IT' => __('Tatar', 'bin-contact'),
			'TE' => __('Telugu', 'bin-contact'),
			'TH' => __('Thai', 'bin-contact'),
			'BO' => __('Tibetan', 'bin-contact'),
			'TO' => __('Tonga', 'bin-contact'),
			'TR' => __('Turkish', 'bin-contact'),
			'UK' => __('Ukranian', 'bin-contact'),
			'UR' => __('Urdu', 'bin-contact'),
			'UZ' => __('Uzbek', 'bin-contact'),
			'VI' => __('Vietnamese', 'bin-contact'),
			'CY' => __('Welsh', 'bin-contact'),
			'XH' => __('Xhosa', 'bin-contact'),
		];
	}
	
	static function formCounty()
	{
		return [
			0 => 'AF',
			1 => 'AX',
			2 => 'AL',
			3 => 'DZ',
			4 => 'AS',
			5 => 'AD',
			6 => 'AO',
			7 => 'AI',
			8 => 'AQ',
			9 => 'AG',
			10 => 'AR',
			11 => 'AM',
			12 => 'AW',
			13 => 'AU',
			14 => 'AT',
			15 => 'AZ',
			16 => 'BS',
			17 => 'BH',
			18 => 'BD',
			19 => 'BB',
			20 => 'BY',
			21 => 'BE',
			22 => 'BZ',
			23 => 'BJ',
			24 => 'BM',
			25 => 'BT',
			26 => 'BO',
			27 => 'BQ',
			28 => 'BA',
			29 => 'BW',
			30 => 'BV',
			31 => 'BR',
			32 => 'IO',
			33 => 'BN',
			34 => 'BG',
			35 => 'BF',
			36 => 'BI',
			37 => 'KH',
			38 => 'CM',
			39 => 'CA',
			40 => 'CV',
			41 => 'KY',
			42 => 'CF',
			43 => 'TD',
			44 => 'CL',
			45 => 'CN',
			46 => 'CX',
			47 => 'CC',
			48 => 'CO',
			49 => 'KM',
			50 => 'CG',
			51 => 'CD',
			52 => 'CK',
			53 => 'CR',
			54 => 'CI',
			55 => 'HR',
			56 => 'CU',
			57 => 'CW',
			58 => 'CY',
			59 => 'CZ',
			60 => 'DK',
			61 => 'DJ',
			62 => 'DM',
			63 => 'DO',
			64 => 'EC',
			65 => 'EG',
			66 => 'SV',
			67 => 'GQ',
			68 => 'ER',
			69 => 'EE',
			70 => 'ET',
			71 => 'FK',
			72 => 'FO',
			73 => 'FJ',
			74 => 'FI',
			75 => 'FR',
			76 => 'GF',
			77 => 'PF',
			78 => 'TF',
			79 => 'GA',
			80 => 'GM',
			81 => 'GE',
			82 => 'DE',
			83 => 'GH',
			84 => 'GI',
			85 => 'GR',
			86 => 'GL',
			87 => 'GD',
			88 => 'GP',
			89 => 'GU',
			90 => 'GT',
			91 => 'GG',
			92 => 'GN',
			93 => 'GW',
			94 => 'GY',
			95 => 'HT',
			96 => 'HM',
			97 => 'VA',
			98 => 'HN',
			99 => 'HK',
			100 => 'HU',
			101 => 'IS',
			102 => 'IN',
			103 => 'ID',
			104 => 'IR',
			105 => 'IQ',
			106 => 'IE',
			107 => 'IM',
			108 => 'IL',
			109 => 'IT',
			110 => 'JM',
			111 => 'JP',
			112 => 'JE',
			113 => 'JO',
			114 => 'KZ',
			115 => 'KE',
			116 => 'KI',
			117 => 'KP',
			118 => 'KR',
			119 => 'KW',
			120 => 'KG',
			121 => 'LA',
			122 => 'LV',
			123 => 'LB',
			124 => 'LS',
			125 => 'LR',
			126 => 'LY',
			127 => 'LI',
			128 => 'LT',
			129 => 'LU',
			130 => 'MO',
			131 => 'MK',
			132 => 'MG',
			133 => 'MW',
			134 => 'MY',
			135 => 'MV',
			136 => 'ML',
			137 => 'MT',
			138 => 'MH',
			139 => 'MQ',
			140 => 'MR',
			141 => 'MU',
			142 => 'YT',
			143 => 'MX',
			144 => 'FM',
			145 => 'MD',
			146 => 'MC',
			147 => 'MN',
			148 => 'ME',
			149 => 'MS',
			150 => 'MA',
			151 => 'MZ',
			152 => 'MM',
			153 => 'NA',
			154 => 'NR',
			155 => 'NP',
			156 => 'NL',
			157 => 'NC',
			158 => 'NZ',
			159 => 'NI',
			160 => 'NE',
			161 => 'NG',
			162 => 'NU',
			163 => 'NF',
			164 => 'MP',
			165 => 'NO',
			166 => 'OM',
			167 => 'PK',
			168 => 'PW',
			169 => 'PS',
			170 => 'PA',
			171 => 'PG',
			172 => 'PY',
			173 => 'PE',
			174 => 'PH',
			175 => 'PN',
			176 => 'PL',
			177 => 'PT',
			178 => 'PR',
			179 => 'QA',
			180 => 'RE',
			181 => 'RO',
			182 => 'RU',
			183 => 'RW',
			184 => 'BL',
			185 => 'SH',
			186 => 'KN',
			187 => 'LC',
			188 => 'MF',
			189 => 'PM',
			190 => 'VC',
			191 => 'WS',
			192 => 'SM',
			193 => 'ST',
			194 => 'SA',
			195 => 'SN',
			196 => 'RS',
			197 => 'SC',
			198 => 'SL',
			199 => 'SG',
			200 => 'SX',
			201 => 'SK',
			202 => 'SI',
			203 => 'SB',
			204 => 'SO',
			205 => 'ZA',
			206 => 'GS',
			207 => 'SS',
			208 => 'ES',
			209 => 'LK',
			210 => 'SD',
			211 => 'SR',
			212 => 'SJ',
			213 => 'SZ',
			214 => 'SE',
			215 => 'CH',
			216 => 'SY',
			217 => 'TW',
			218 => 'TJ',
			219 => 'TZ',
			220 => 'TH',
			221 => 'TL',
			222 => 'TG',
			223 => 'TK',
			224 => 'TO',
			225 => 'TT',
			226 => 'TN',
			227 => 'TR',
			228 => 'TM',
			229 => 'TC',
			230 => 'TV',
			231 => 'UG',
			232 => 'UA',
			233 => 'AE',
			234 => 'GB',
			235 => 'US',
			236 => 'UM',
			237 => 'UY',
			238 => 'UZ',
			239 => 'VU',
			240 => 'VE',
			241 => 'VN',
			242 => 'VG',
			243 => 'VI',
			244 => 'WF',
			245 => 'EH',
			246 => 'YE',
			247 => 'ZM',
			248 => 'ZW',
		];
	}
	
	static function formCountyValue()
	{
		return [
			'AF' => __('Afghanistan', 'bin-contact'),
			'AX' => __('Åland Islands', 'bin-contact'),
			'AL' => __('Albania', 'bin-contact'),
			'DZ' => __('Algeria', 'bin-contact'),
			'AS' => __('American Samoa', 'bin-contact'),
			'AD' => __('Andorra', 'bin-contact'),
			'AO' => __('Angola', 'bin-contact'),
			'AI' => __('Anguilla', 'bin-contact'),
			'AQ' => __('Antarctica', 'bin-contact'),
			'AG' => __('Antigua and Barbuda', 'bin-contact'),
			'AR' => __('Argentina', 'bin-contact'),
			'AM' => __('Armenia', 'bin-contact'),
			'AW' => __('Aruba', 'bin-contact'),
			'AU' => __('Australia', 'bin-contact'),
			'AT' => __('Austria', 'bin-contact'),
			'AZ' => __('Azerbaijan', 'bin-contact'),
			'BS' => __('Bahamas', 'bin-contact'),
			'BH' => __('Bahrain', 'bin-contact'),
			'BD' => __('Bangladesh', 'bin-contact'),
			'BB' => __('Barbados', 'bin-contact'),
			'BY' => __('Belarus', 'bin-contact'),
			'BE' => __('Belgium', 'bin-contact'),
			'BZ' => __('Belize', 'bin-contact'),
			'BJ' => __('Benin', 'bin-contact'),
			'BM' => __('Bermuda', 'bin-contact'),
			'BT' => __('Bhutan', 'bin-contact'),
			'BO' => __('Bolivia, Plurinational State of', 'bin-contact'),
			'BQ' => __('Bonaire, Sint Eustatius and Saba', 'bin-contact'),
			'BA' => __('Bosnia and Herzegovina', 'bin-contact'),
			'BW' => __('Botswana', 'bin-contact'),
			'BV' => __('Bouvet Island', 'bin-contact'),
			'BR' => __('Brazil', 'bin-contact'),
			'IO' => __('British Indian Ocean Territory', 'bin-contact'),
			'BN' => __('Brunei Darussalam', 'bin-contact'),
			'BG' => __('Bulgaria', 'bin-contact'),
			'BF' => __('Burkina Faso', 'bin-contact'),
			'BI' => __('Burundi', 'bin-contact'),
			'KH' => __('Cambodia', 'bin-contact'),
			'CM' => __('Cameroon', 'bin-contact'),
			'CA' => __('Canada', 'bin-contact'),
			'CV' => __('Cape Verde', 'bin-contact'),
			'KY' => __('Cayman Islands', 'bin-contact'),
			'CF' => __('Central African Republic', 'bin-contact'),
			'TD' => __('Chad', 'bin-contact'),
			'CL' => __('Chile', 'bin-contact'),
			'CN' => __('China', 'bin-contact'),
			'CX' => __('Christmas Island', 'bin-contact'),
			'CC' => __('Cocos (Keeling) Islands', 'bin-contact'),
			'CO' => __('Colombia', 'bin-contact'),
			'KM' => __('Comoros', 'bin-contact'),
			'CG' => __('Congo', 'bin-contact'),
			'CD' => __('Congo, the Democratic Republic of the', 'bin-contact'),
			'CK' => __('Cook Islands', 'bin-contact'),
			'CR' => __('Costa Rica', 'bin-contact'),
			'CI' => __('Côte d\'Ivoire', 'bin-contact'),
			'HR' => __('Croatia', 'bin-contact'),
			'CU' => __('Cuba', 'bin-contact'),
			'CW' => __('Curaçao', 'bin-contact'),
			'CY' => __('Cyprus', 'bin-contact'),
			'CZ' => __('Czech Republic', 'bin-contact'),
			'DK' => __('Denmark', 'bin-contact'),
			'DJ' => __('Djibouti', 'bin-contact'),
			'DM' => __('Dominica', 'bin-contact'),
			'DO' => __('Dominican Republic', 'bin-contact'),
			'EC' => __('Ecuador', 'bin-contact'),
			'EG' => __('Egypt', 'bin-contact'),
			'SV' => __('El Salvador', 'bin-contact'),
			'GQ' => __('Equatorial Guinea', 'bin-contact'),
			'ER' => __('Eritrea', 'bin-contact'),
			'EE' => __('Estonia', 'bin-contact'),
			'ET' => __('Ethiopia', 'bin-contact'),
			'FK' => __('Falkland Islands (Malvinas)', 'bin-contact'),
			'FO' => __('Faroe Islands', 'bin-contact'),
			'FJ' => __('Fiji', 'bin-contact'),
			'FI' => __('Finland', 'bin-contact'),
			'FR' => __('France', 'bin-contact'),
			'GF' => __('French Guiana', 'bin-contact'),
			'PF' => __('French Polynesia', 'bin-contact'),
			'TF' => __('French Southern Territories', 'bin-contact'),
			'GA' => __('Gabon', 'bin-contact'),
			'GM' => __('Gambia', 'bin-contact'),
			'GE' => __('Georgia', 'bin-contact'),
			'DE' => __('Germany', 'bin-contact'),
			'GH' => __('Ghana', 'bin-contact'),
			'GI' => __('Gibraltar', 'bin-contact'),
			'GR' => __('Greece', 'bin-contact'),
			'GL' => __('Greenland', 'bin-contact'),
			'GD' => __('Grenada', 'bin-contact'),
			'GP' => __('Guadeloupe', 'bin-contact'),
			'GU' => __('Guam', 'bin-contact'),
			'GT' => __('Guatemala', 'bin-contact'),
			'GG' => __('Guernsey', 'bin-contact'),
			'GN' => __('Guinea', 'bin-contact'),
			'GW' => __('Guinea-Bissau', 'bin-contact'),
			'GY' => __('Guyana', 'bin-contact'),
			'HT' => __('Haiti', 'bin-contact'),
			'HM' => __('Heard Island and McDonald Islands', 'bin-contact'),
			'VA' => __('Holy See (Vatican City State)', 'bin-contact'),
			'HN' => __('Honduras', 'bin-contact'),
			'HK' => __('Hong Kong', 'bin-contact'),
			'HU' => __('Hungary', 'bin-contact'),
			'IS' => __('Iceland', 'bin-contact'),
			'IN' => __('India', 'bin-contact'),
			'ID' => __('Indonesia', 'bin-contact'),
			'IR' => __('Iran, Islamic Republic of', 'bin-contact'),
			'IQ' => __('Iraq', 'bin-contact'),
			'IE' => __('Ireland', 'bin-contact'),
			'IM' => __('Isle of Man', 'bin-contact'),
			'IL' => __('Israel', 'bin-contact'),
			'IT' => __('Italy', 'bin-contact'),
			'JM' => __('Jamaica', 'bin-contact'),
			'JP' => __('Japan', 'bin-contact'),
			'JE' => __('Jersey', 'bin-contact'),
			'JO' => __('Jordan', 'bin-contact'),
			'KZ' => __('Kazakhstan', 'bin-contact'),
			'KE' => __('Kenya', 'bin-contact'),
			'KI' => __('Kiribati', 'bin-contact'),
			'KP' => __('Korea, Democratic People\'s Republic of', 'bin-contact'),
			'KR' => __('Korea, Republic of', 'bin-contact'),
			'KW' => __('Kuwait', 'bin-contact'),
			'KG' => __('Kyrgyzstan', 'bin-contact'),
			'LA' => __('Lao People\'s Democratic Republic', 'bin-contact'),
			'LV' => __('Latvia', 'bin-contact'),
			'LB' => __('Lebanon', 'bin-contact'),
			'LS' => __('Lesotho', 'bin-contact'),
			'LR' => __('Liberia', 'bin-contact'),
			'LY' => __('Libya', 'bin-contact'),
			'LI' => __('Liechtenstein', 'bin-contact'),
			'LT' => __('Lithuania', 'bin-contact'),
			'LU' => __('Luxembourg', 'bin-contact'),
			'MO' => __('Macao', 'bin-contact'),
			'MK' => __('Macedonia, the former Yugoslav Republic of', 'bin-contact'),
			'MG' => __('Madagascar', 'bin-contact'),
			'MW' => __('Malawi', 'bin-contact'),
			'MY' => __('Malaysia', 'bin-contact'),
			'MV' => __('Maldives', 'bin-contact'),
			'ML' => __('Mali', 'bin-contact'),
			'MT' => __('Malta', 'bin-contact'),
			'MH' => __('Marshall Islands', 'bin-contact'),
			'MQ' => __('Martinique', 'bin-contact'),
			'MR' => __('Mauritania', 'bin-contact'),
			'MU' => __('Mauritius', 'bin-contact'),
			'YT' => __('Mayotte', 'bin-contact'),
			'MX' => __('Mexico', 'bin-contact'),
			'FM' => __('Micronesia, Federated States of', 'bin-contact'),
			'MD' => __('Moldova, Republic of', 'bin-contact'),
			'MC' => __('Monaco', 'bin-contact'),
			'MN' => __('Mongolia', 'bin-contact'),
			'ME' => __('Montenegro', 'bin-contact'),
			'MS' => __('Montserrat', 'bin-contact'),
			'MA' => __('Morocco', 'bin-contact'),
			'MZ' => __('Mozambique', 'bin-contact'),
			'MM' => __('Myanmar', 'bin-contact'),
			'NA' => __('Namibia', 'bin-contact'),
			'NR' => __('Nauru', 'bin-contact'),
			'NP' => __('Nepal', 'bin-contact'),
			'NL' => __('Netherlands', 'bin-contact'),
			'NC' => __('New Caledonia', 'bin-contact'),
			'NZ' => __('New Zealand', 'bin-contact'),
			'NI' => __('Nicaragua', 'bin-contact'),
			'NE' => __('Niger', 'bin-contact'),
			'NG' => __('Nigeria', 'bin-contact'),
			'NU' => __('Niue', 'bin-contact'),
			'NF' => __('Norfolk Island', 'bin-contact'),
			'MP' => __('Northern Mariana Islands', 'bin-contact'),
			'NO' => __('Norway', 'bin-contact'),
			'OM' => __('Oman', 'bin-contact'),
			'PK' => __('Pakistan', 'bin-contact'),
			'PW' => __('Palau', 'bin-contact'),
			'PS' => __('Palestinian Territory, Occupied', 'bin-contact'),
			'PA' => __('Panama', 'bin-contact'),
			'PG' => __('Papua New Guinea', 'bin-contact'),
			'PY' => __('Paraguay', 'bin-contact'),
			'PE' => __('Peru', 'bin-contact'),
			'PH' => __('Philippines', 'bin-contact'),
			'PN' => __('Pitcairn', 'bin-contact'),
			'PL' => __('Poland', 'bin-contact'),
			'PT' => __('Portugal', 'bin-contact'),
			'PR' => __('Puerto Rico', 'bin-contact'),
			'QA' => __('Qatar', 'bin-contact'),
			'RE' => __('Réunion', 'bin-contact'),
			'RO' => __('Romania', 'bin-contact'),
			'RU' => __('Russian Federation', 'bin-contact'),
			'RW' => __('Rwanda', 'bin-contact'),
			'BL' => __('Saint Barthélemy', 'bin-contact'),
			'SH' => __('Saint Helena, Ascension and Tristan da Cunha', 'bin-contact'),
			'KN' => __('Saint Kitts and Nevis', 'bin-contact'),
			'LC' => __('Saint Lucia', 'bin-contact'),
			'MF' => __('Saint Martin (French part)', 'bin-contact'),
			'PM' => __('Saint Pierre and Miquelon', 'bin-contact'),
			'VC' => __('Saint Vincent and the Grenadines', 'bin-contact'),
			'WS' => __('Samoa', 'bin-contact'),
			'SM' => __('San Marino', 'bin-contact'),
			'ST' => __('Sao Tome and Principe', 'bin-contact'),
			'SA' => __('Saudi Arabia', 'bin-contact'),
			'SN' => __('Senegal', 'bin-contact'),
			'RS' => __('Serbia', 'bin-contact'),
			'SC' => __('Seychelles', 'bin-contact'),
			'SL' => __('Sierra Leone', 'bin-contact'),
			'SG' => __('Singapore', 'bin-contact'),
			'SX' => __('Sint Maarten (Dutch part)', 'bin-contact'),
			'SK' => __('Slovakia', 'bin-contact'),
			'SI' => __('Slovenia', 'bin-contact'),
			'SB' => __('Solomon Islands', 'bin-contact'),
			'SO' => __('Somalia', 'bin-contact'),
			'ZA' => __('South Africa', 'bin-contact'),
			'GS' => __('South Georgia and the South Sandwich Islands', 'bin-contact'),
			'SS' => __('South Sudan', 'bin-contact'),
			'ES' => __('Spain', 'bin-contact'),
			'LK' => __('Sri Lanka', 'bin-contact'),
			'SD' => __('Sudan', 'bin-contact'),
			'SR' => __('Suriname', 'bin-contact'),
			'SJ' => __('Svalbard and Jan Mayen', 'bin-contact'),
			'SZ' => __('Swaziland', 'bin-contact'),
			'SE' => __('Sweden', 'bin-contact'),
			'CH' => __('Switzerland', 'bin-contact'),
			'SY' => __('Syrian Arab Republic', 'bin-contact'),
			'TW' => __('Taiwan, Province of China', 'bin-contact'),
			'TJ' => __('Tajikistan', 'bin-contact'),
			'TZ' => __('Tanzania, United Republic of', 'bin-contact'),
			'TH' => __('Thailand', 'bin-contact'),
			'TL' => __('Timor-Leste', 'bin-contact'),
			'TG' => __('Togo', 'bin-contact'),
			'TK' => __('Tokelau', 'bin-contact'),
			'TO' => __('Tonga', 'bin-contact'),
			'TT' => __('Trinidad and Tobago', 'bin-contact'),
			'TN' => __('Tunisia', 'bin-contact'),
			'TR' => __('Turkey', 'bin-contact'),
			'TM' => __('Turkmenistan', 'bin-contact'),
			'TC' => __('Turks and Caicos Islands', 'bin-contact'),
			'TV' => __('Tuvalu', 'bin-contact'),
			'UG' => __('Uganda', 'bin-contact'),
			'UA' => __('Ukraine', 'bin-contact'),
			'AE' => __('United Arab Emirates', 'bin-contact'),
			'GB' => __('United Kingdom', 'bin-contact'),
			'US' => __('United States', 'bin-contact'),
			'UM' => __('United States Minor Outlying Islands', 'bin-contact'),
			'UY' => __('Uruguay', 'bin-contact'),
			'UZ' => __('Uzbekistan', 'bin-contact'),
			'VU' => __('Vanuatu', 'bin-contact'),
			'VE' => __('Venezuela, Bolivarian Republic of', 'bin-contact'),
			'VN' => __('Viet Nam', 'bin-contact'),
			'VG' => __('Virgin Islands, British', 'bin-contact'),
			'VI' => __('Virgin Islands, U.S.', 'bin-contact'),
			'WF' => __('Wallis and Futuna', 'bin-contact'),
			'EH' => __('Western Sahara', 'bin-contact'),
			'YE' => __('Yemen', 'bin-contact'),
			'ZM' => __('Zambia', 'bin-contact'),
			'ZW' => __('Zimbabwe', 'bin-contact'),
		];
	}
}