/**
 * Leaflet
 */
jQuery(document).ready(function($)
{
	if(jQuery('.bin_contact_leaflet_map').length)
	{
		// unique id
		var mapId = 'cwp-leaflet-'+([1e7]+-1e3+-4e3+-8e3+-1e11).replace(/[018]/g, c => (c ^ crypto.getRandomValues(new Uint8Array(1))[0] & 15 >> c / 4).toString(16));

		// wrapper map
		var mapWrapper = jQuery('.bin_contact_leaflet_map');

		// get initial settings or fallback
		var initialHeight = mapWrapper.data('leaflet-height') ? mapWrapper.data('leaflet-height') : '500px';
		var initialZoom = mapWrapper.data('leaflet-zoom') ? mapWrapper.data('leaflet-zoom') : 14;
		var initialLat = mapWrapper.data('leaflet-lat') ? mapWrapper.data('leaflet-lat') : '46.922882';
		var initialLng = mapWrapper.data('leaflet-lng') ? mapWrapper.data('leaflet-lng') : '8.378468';

		var initialMarkerLat = jQuery('#bin_contact_lat').val() ? jQuery('#bin_contact_lat').val() : '46.96962521437086';
		var initialMarkerLng = jQuery('#bin_contact_lng').val() ? jQuery('#bin_contact_lng').val() : '9.688000023157995';
		var initialCenterLat = jQuery('#bin_contact_lat').val() ? jQuery('#bin_contact_lat').val() : initialLat;
		var initialCenterLng = jQuery('#bin_contact_lng').val() ? jQuery('#bin_contact_lng').val() : initialLng;

		// append div to insert map
		var mapContainer = $('<div id="'+mapId+'"></div>').appendTo(mapWrapper);
		mapContainer.css({ height:initialHeight });

		var mapLeaflet = L.map(mapId, {
			scrollWheelZoom: true,
			wheelDebounceTime: 500
		}).setView([initialCenterLat, initialCenterLng], initialZoom);
		L.tileLayer(bin_contact_back.osm_tiles, {
			id: 'mapbox.streets',
			attribution: bin_contact_back.osm_attribution
		}).addTo(mapLeaflet);

		var leafletMarker = L.marker([initialMarkerLat, initialMarkerLng]).addTo(mapLeaflet);
		leafletMarker.bindPopup(bin_contact_back.current);

		mapLeaflet.on('click', function(e) {
			L.popup()
				.setLatLng(e.latlng)
				.setContent('<a href="#" class="button cwp-leaflet-address-select" data-lat="'+e.latlng.lat+'" data-lng="'+e.latlng.lng+'">'+bin_contact_back.update+'</a>')
				.openOn(mapLeaflet);
		});

		jQuery('#cwp-leaflet').on('click', '.cwp-leaflet-address-show', function(e)
		{
			e.preventDefault();

			mapLeaflet.setView([jQuery(this).data('lat'), jQuery(this).data('lng')]);		
			L.popup()
				.setLatLng([ jQuery(this).data('lat'), jQuery(this).data('lng') ])
				.setContent('<a href="#" class="button cwp-leaflet-address-select" data-lat="'+jQuery(this).data('lat')+'" data-lng="'+jQuery(this).data('lng')+'">'+bin_contact_back.update+'</a>')
				.openOn(mapLeaflet);
		});

		jQuery('#cwp-leaflet').on('click', '.cwp-leaflet-address-select', function(e)
		{
			e.preventDefault();

			leafletMarker.setLatLng([ jQuery(this).data('lat'), jQuery(this).data('lng') ]);

			if(jQuery(this).data('lat')) { jQuery('#bin_contact_lat').val(jQuery(this).data('lat')); }
			if(jQuery(this).data('lng')) { jQuery('#bin_contact_lng').val(jQuery(this).data('lng')); }

			mapLeaflet.closePopup();
		});
	}
});

/**
 * search by address
 */
jQuery(document).ready(function($)
{
	$('#bin_contact_street_and_number, #bin_contact_city, #bin_contact_zip').on('keyup', function(e)
	{
		var searchArray = [];
		if(jQuery('#bin_contact_street_and_number')) { searchArray.push(jQuery('#bin_contact_street_and_number').val()); }
		if(jQuery('#bin_contact_city')) { searchArray.push(jQuery('#bin_contact_city').val()); }
		if(jQuery('#bin_contact_zip')) { searchArray.push(jQuery('#bin_contact_zip').val()); }
		
		var searchString = searchArray.join(', ');
		
		jQuery('#cwp-leaflet-address').val(searchString);
	});
	
	$('#cwp-leaflet-address').on('keypress', function(e) {
		if(e.which === 13)
		{
			e.preventDefault();
			jQuery('#cwp-leaflet-search').trigger('click');
		}
   });
	
	$('#cwp-leaflet').on('click', '#cwp-leaflet-search', function(e)
	{
		e.preventDefault();
		
		var inp = jQuery(this).closest('#cwp-leaflet').find('#cwp-leaflet-address');
		var xmlhttp = new XMLHttpRequest();
		var url = "https://nominatim.openstreetmap.org/search?format=json&limit=10&q="+inp.val();
		xmlhttp.onreadystatechange = function()
		{
			if(this.readyState === 4 && this.status === 200)
			{
				var out = '';
				var responseArr = JSON.parse(this.responseText);
	
				if(responseArr.length > 0)
				{
					jQuery.each(responseArr, function(key, value)
					{
						//console.log(value);
						out += '<a href="#" class="cwp-leaflet-address-show" data-lat="'+value.lat+'" data-lng="'+value.lon+'">'+value.display_name+'</a><br>';
					});
				}
				else
				{
					out += '<span style="background:yellow">'+bin_contact_back.sorry+'</span>';
				}
				
				jQuery('.cwp-leaflet-result').html(out);
			}
		};
		xmlhttp.open("GET", url, true);
		xmlhttp.send();
	});
});

jQuery(document).ready(function($)
{
	/**
	 * ajax load widget data
	 */
	$('#bin_contact_widget').on('click', '.bin_contact_ajax', function(e)
	{
		e.preventDefault();
		trigger = $(this);
		trigger.append('<div class="bin_contact_ajax_spinner"></div>');
		
		$.post(ajaxurl, trigger.data('attributes'), function(response)
		{
			trigger.find('.bin_contact_ajax_spinner').remove();
			$(trigger.data('target')).html(response);
		});
	});
	
	/**
	 * dismiss admin dependency notice
	 */
	$('#bin_contact_admin_notice').on('click', '.bin_contact_admin_notice_dismiss', function(e)
	{
		e.preventDefault();
		
		if(confirm('Are you sure?'))
		{
			trigger = $(this);
			trigger.append('<div class="bin_contact_ajax_spinner"></div>');

			$.post(ajaxurl, { action: 'bin_contact_admin_notice_dismiss' }, function(response)
			{
				trigger.find('.bin_contact_ajax_spinner').remove();
				$('#bin_contact_admin_notice').remove();
			});
		}
	});
});

/**
 * Form element conditional logic
 */
jQuery(document).ready(function($)
{
	dataCondition();
	function dataCondition()
	{
		$('[data-bin-contact-condition]').each(function()
		{
			// initial show
			$input = $(this);
			$condition = $input.data('bin-contact-condition').split(',');
			$parent = $input.data('bin-contact-condition-parent');

			if(typeof $parent === 'undefined' || $('.'+$parent).is(':not(:hidden)'))
			{
				$.each($condition, function(index, value)
				{
					$data = value.split(':');
					
					if($input.is('[type="checkbox"]') && $input.is(':not(:checked)'))
					{
						return;
					}
					
					if($input.val() === $data[0])
					{	
						$('.'+$data[1]).removeClass('bin_contact_condition_hidden');
					}
				});
			}
			
			// click function
			$(this).bind({
				change: function()
				{
					$input = $(this);
					$condition = $input.data('bin-contact-condition').split(',');
					$parent = $input.data('bin-contact-condition-parent');

					// hide all
					$.each($condition, function(index, value)
					{
						$data = value.split(':');
						$('.'+$data[1]).addClass('bin_contact_condition_hidden');
					});

					// show clicked
					$.each($condition, function(index, value)
					{						
						$data = value.split(':');

						if($input.is('[type="checkbox"]') && $input.is(':not(:checked)'))
						{
							return;
						}

						if((typeof $parent === 'undefined' || $('.'+$parent).is(':not(:hidden)')) && $input.val() === $data[0])
						{
							$('.'+$data[1]).removeClass('bin_contact_condition_hidden');
						}

						$('[data-bin-contact-condition-parent="'+$data[1]+'"]').trigger('change');
					});
				}
			});
		});
	}
});

/**
 * Media
 * Load media uploader on pages with our custom metabox
 */
jQuery(document).ready(function($)
{
	// Instantiates the variable that holds the media library frame.
	var metaImageFrame;

	$('.bin_contact_media_select').on('click', '.bin_contact_empty_field', function(e)
	{
		e.preventDefault();
		$(this).parent('div').find('input[type=url]').val('');
	});

	$('.bin_contact_media_select').on('click', '[data-media-uploader-target]', function(e)
	{
		e.preventDefault();
		
		// return value field
		var field = $(this).data('media-uploader-target');
		
		// Sets up the media library frame
		metaImageFrame = wp.media.frames.metaImageFrame = wp.media({
			title: 'Title',
			button: { text: 'Use this file' },
		});

		// Runs when an image is selected.
		metaImageFrame.on('select', function()
		{
			// Grabs the attachment selection and creates a JSON representation of the model.
			var media_attachment = metaImageFrame.state().get('selection').first().toJSON();

			// Sends the attachment URL to our custom image input field.
			$(field).val(media_attachment.url);
		});

		// Opens the media library frame.
		metaImageFrame.open();
	});
});