/**
 * Leaflet
 */
jQuery(document).ready(function($)
{
	$('.leaflet-map').each(function()
	{
		// unique id
		var mapId = 'leaflet-'+([1e7]+-1e3+-4e3+-8e3+-1e11).replace(/[018]/g, c => (c ^ crypto.getRandomValues(new Uint8Array(1))[0] & 15 >> c / 4).toString(16));
		
		// wrapper map
		var mapWrapper = $(this);
		
		// get initial settings or fallback
		var initialHeight = mapWrapper.data('leaflet-height') ? mapWrapper.data('leaflet-height') : '500px';
		var initialZoom = mapWrapper.data('leaflet-zoom') ? mapWrapper.data('leaflet-zoom') : 8;
		var initialLat = mapWrapper.data('leaflet-lat') ? mapWrapper.data('leaflet-lat') : '46.922882';
		var initialLng = mapWrapper.data('leaflet-lng') ? mapWrapper.data('leaflet-lng') : '8.378468';
		
		// append div to insert map
		var mapContainer = $('<div id="'+mapId+'"></div>').appendTo(mapWrapper);
		mapContainer.css({ height: initialHeight });
		
		var mapLeaflet = L.map(mapId, {
			scrollWheelZoom: true,
			wheelDebounceTime: 500
		}).setView([initialLat, initialLng], initialZoom);

		//console.log(bin_contact_front);

		L.tileLayer(bin_contact_front.osm_tiles, {
			id: 'mapbox.streets',
			attribution: bin_contact_front.osm_attribution
		}).addTo(mapLeaflet);
		
		if(mapWrapper.data('leaflet-markers'))
		{
			jQuery.each(mapWrapper.data('leaflet-markers'), function(key, value)
			{
				/* prepare marker and marker icon (if any) */
				var marker = '';
				if(value.marker_type === 'custom' && value.marker_custom)
				{
					var iconUrl = value.marker_custom;
					var iconWidth = value.marker_custom_width;
					var iconHeight = value.marker_custom_height;
					
					if(value.marker_custom2x)
					{
						iconUrl = value.marker_custom2x;
						iconWidth = Math.round(value.marker_custom2x_width/2);
						iconHeight = Math.round(value.marker_custom2x_height/2);
					}
					
					customIcon = L.icon({
						iconUrl: iconUrl,
						iconSize: [iconWidth, iconHeight],
						iconAnchor: [Math.round(iconWidth/2),8]
					});
					
					marker = L.marker([ value.lat, value.lng], {icon: customIcon}).addTo(mapLeaflet);
				}
				else
				{
					marker = L.marker([ value.lat, value.lng]).addTo(mapLeaflet);
				}
				
				/* prepare popup text */
				var popText = '';
				if(value.company)
				{
					popText += '<strong>'+value.company+'</strong><br>';
				}
				if(value.first_name || value.last_name)
				{
					if(value.company === '' || value.company === undefined)
					{
						popText += '<strong>';
					}
					if(value.first_name && value.last_name)
					{
						popText += value.first_name+' '+value.last_name;
					}
					else
					{
						popText += value.first_name+value.last_name;
					}
					if(value.company === '' || value.company === undefined)
					{
						popText += '</strong>';
					}
					popText += '<br>';
				}
				if(value.street_and_number)
				{
					popText += value.street_and_number+'<br>';
				}
				if(value.zip || value.place)
				{
					if(value.zip && value.place)
					{
						popText += value.zip+' '+value.place;
					}
					else
					{
						popText += value.zip+value.place;
					}
					popText += '<br>';
				}
				if(value.website || value.email || value.mobile || value.phone_work || value.phone_private)
				{
					popText += '<br>';
					if(value.email)
					{
						popText += value.email+'<br>';
					}
					if(value.mobile)
					{
						popText += value.mobile+'<br>';
					}
					if(value.phone_private)
					{
						popText += value.phone_private+'<br>';
					}
					if(value.phone_work)
					{
						popText += value.phone_work+'<br>';
					}
					if(value.website)
					{
						popText += value.website+'<br>';
					}
				}
				
				/* add popup text to marker */
				marker.bindPopup(popText);
			});
		}
	});
});