<?php

/* 
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

class BinContact_Customposttype
{
	public function __construct()
	{
		// register custom post type
		add_action('init', [$this, 'init']);
		
		// extend custom post type
		add_action('add_meta_boxes_contact', [$this, 'add_meta_boxes']);
		add_action('save_post_contact', [$this, 'save_post']);
		
		// extend columns view
		add_action('admin_head-edit.php', [$this, 'contact_title'], 10);
		add_filter('manage_edit-contact_columns',  [$this, 'contact_columns'], 10);
		add_filter('manage_edit-contact_sortable_columns', [$this, 'contact_sortable_columns'], 10);
		add_action('manage_contact_posts_custom_column',  [$this, 'contact_custom_column'], 10, 2);
		
		// enhance backend search
		add_filter('posts_join', [$this, 'contact_search_join']);
		add_filter('posts_where', [$this, 'contact_search_where']);
		add_filter('posts_distinct', [$this, 'contact_search_distinct']);
	}
	
	function init()
	{
		register_post_type('contact', [
			'labels' => [
				'name' => __('Contacts', 'bin-contact'),
				'singular_name' => __('Contact', 'bin-contact'),
				'add_new_item' => __('Add new contact', 'bin-contact'),
				'edit_item' => __('Edit contact', 'bin-contact'),
				'new_item' => __('New contact', 'bin-contact'),
				'not_found' => __('No contact found', 'bin-contact'),
				'all_items' => __('All contacts', 'bin-contact')
			],
			'public' => false,
			'exclude_from_search' => true,
			'publicly_queryable' => false,
			'show_ui' => true,
			'show_in_menu' => true,
			'show_in_rest' => true,
			'has_archive' => false,
			'map_meta_cap' => true,
			'menu_icon' => 'dashicons-groups',
			'supports' => false,
			'taxonomies' => [],
			'rewrite' => ['slug' => 'contact']
		]);
	}
	
	function contact_title()
	{
		global $post_type;
		if($post_type === 'contact')
		{
			add_filter('the_title', [$this, 'contact_title_build'], 100, 2);	
		}
	}
	
	function contact_title_build($title, $id)
	{
		$first = get_post_meta($id, 'bin_contact_first_name', true);
		$last = get_post_meta($id, 'bin_contact_last_name', true);
		
		if($first || $last) { return $first.' '.$last; }
		return __('(no name)', 'bin-contact');
	}
	
	function contact_columns($columns)
	{
		return [
			'cb' => '<input type="checkbox" />',
			'title' => __('Name', 'bin-contact'),
			'email' => __('Email', 'bin-contact'),
			'place' => __('Zip/Place', 'bin-contact'),
			'mobile' => __('Mobile', 'bin-contact'),
			'taxonomy-contact_group' => __('Groups', 'bin-contact'),
			'date' => __('Date', 'bin-contact')
		];
	}
	
	function contact_sortable_columns( $columns )
	{
		$columns['place'] = 'place';
		$columns['email'] = 'email';
		$columns['mobile'] = 'mobile';
		return $columns;
	}

	function contact_custom_column($column, $post_id)
	{
		if($column === 'place') { echo get_post_meta($post_id, 'bin_contact_zip', true).' '.get_post_meta($post_id, 'bin_contact_city', true); }
		if($column === 'email') { echo '<a href="mailto:'.get_post_meta($post_id, 'bin_contact_email', true).'">'.get_post_meta($post_id, 'bin_contact_email', true).'</a>'; }
		if($column === 'mobile') { echo get_post_meta($post_id, 'bin_contact_mobile', true); }
	}
	
	function add_meta_boxes($post)
	{
		add_meta_box('bin_contact_metabox_person', __('Personal data', 'bin-contact'), [$this, 'bin_contact_metabox_person_build'], 'contact', 'normal');
		add_meta_box('bin_contact_metabox_contact', __('Contact data', 'bin-contact'), [$this, 'bin_contact_metabox_contact_build'], 'contact', 'normal');
		add_meta_box('bin_contact_metabox_socialmedia', __('Website and Social Media', 'bin-contact'), [$this, 'bin_contact_metabox_socialmedia_build'], 'contact', 'normal');
		add_meta_box('bin_contact_metabox_legal', __('Legal', 'bin-contact'), [$this, 'bin_contact_metabox_legal_build'], 'contact', 'normal');
		add_meta_box('bin_contact_metabox_map', __('Map', 'bin-contact'), [$this, 'bin_contact_metabox_map_build'], 'contact', 'normal');
	}
	
	function contact_search_join($join)
	{
		global $pagenow, $wpdb;

		// I want the filter only when performing a search on edit page of Custom Post Type named "contact".
		if(is_admin() && 'edit.php' === $pagenow && 'contact' === $_GET['post_type'] && !empty($_GET['s']))
		{    
			$join .= 'LEFT JOIN '.$wpdb->postmeta.' ON '.$wpdb->posts.'.ID = '.$wpdb->postmeta.'.post_id ';
		}
		return $join;
	}
	
	function contact_search_where($where)
	{
		global $pagenow, $wpdb;

		// I want the filter only when performing a search on edit page of Custom Post Type named "contact".
		if(is_admin() && 'edit.php' === $pagenow && 'contact' === $_GET['post_type'] && !empty($_GET['s']))
		{
			$where = preg_replace("/\(\s*".$wpdb->posts.".post_title\s+LIKE\s*(\'[^\']+\')\s*\)/", "(".$wpdb->posts.".post_title LIKE $1) OR (".$wpdb->postmeta.".meta_value LIKE $1)", $where);
		}
		return $where;
	}
	
	function contact_search_distinct($where)
	{
		global $pagenow, $wpdb;

		if(is_admin() && $pagenow=='edit.php' && $_GET['post_type']=='contact' && !empty($_GET['s']))
		{
			return "DISTINCT";
		}
		return $where;
	}
	
	function bin_contact_metabox_person_build($post)
	{
		// make sure the form request comes from WordPress
		wp_nonce_field(basename( __FILE__ ), 'bin_contact_meta_box_nonce');

		echo '<table class="form-table">';
			echo '<tbody>';
				echo '<tr>';
					echo '<th>';
						echo '<label for="bin_contact_image">'.BinContact::formTextLabels()['image'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<div class="bin_contact_media_select">';
							echo '<div class="bin_contact_media_field">';
								echo '<input id="bin_contact_image" class="regular-text" type="url"  name="bin_contact_image" value="'.get_post_meta($post->ID, 'bin_contact_image', true).'">';
								echo '<a href="#" class="bin_contact_empty_field"><span class="dashicons dashicons-dismiss"></span></a>';
							echo '</div>';
							echo '<button type="button" class="button" data-media-uploader-target="#bin_contact_image">'.__('Upload Media', 'bin-contact').'</button>';
						echo '</div>';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_company">'.BinContact::formTextLabels()['company'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_company" class="regular-text" type="text" name="bin_contact_company" value="'.get_post_meta($post->ID, 'bin_contact_company', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_salutation">'.BinContact::formTextLabels()['salutation'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<select id="bin_contact_salutation" class="regular-text" type="text" name="bin_contact_salutation">';
							echo '<option value="" '.selected(get_post_meta($post->ID, 'bin_contact_salutation', true), '', false).'>'.__('-- empty --', 'bin-contact').'</option>';
							foreach(BinContact::formSalutation() as $key => $value)
							{
								echo '<option value="'.$key.'" '.selected(get_post_meta($post->ID, 'bin_contact_salutation', true), $key, false).'>'.$value.'</option>';
							}
						echo '</select>';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_name_suffix">'.BinContact::formTextLabels()['name_suffix'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_name_suffix" class="regular-text" type="text" name="bin_contact_name_suffix" value="'.get_post_meta($post->ID, 'bin_contact_name_suffix', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_first_name">'.BinContact::formTextLabels()['first_name'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_first_name" class="regular-text" type="text" name="bin_contact_first_name" value="'.get_post_meta($post->ID, 'bin_contact_first_name', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_last_name">'.BinContact::formTextLabels()['last_name'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_last_name" class="regular-text" type="text" name="bin_contact_last_name" value="'.get_post_meta($post->ID, 'bin_contact_last_name', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_designation">'.BinContact::formTextLabels()['designation'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_designation" class="regular-text" type="text" name="bin_contact_designation" value="'.get_post_meta($post->ID, 'bin_contact_designation', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_polite_form">'.BinContact::formTextLabels()['polite_form'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<select id="bin_contact_polite_form" class="regular-text" type="text" name="bin_contact_polite_form">';
							echo '<option value="" '.selected(get_post_meta($post->ID, 'bin_contact_polite_form', true), '', false).'>'.__('-- empty --', 'bin-contact').'</option>';
							foreach(BinContact::formPoliteform() as $key => $value)
							{
								echo '<option value="'.$key.'" '.selected(get_post_meta($post->ID, 'bin_contact_polite_form', true), $key, false).'>'.$value.'</option>';
							}
						echo '</select>';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_language_of_correspondence">'.BinContact::formTextLabels()['language_of_correspondence'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<select id="bin_contact_language_of_correspondence" class="regular-text" type="text" name="bin_contact_language_of_correspondence">';
							echo '<option value="" '.selected(get_post_meta($post->ID, 'bin_contact_language_of_correspondence', true), '', false).'>'.__('-- empty --', 'bin-contact').'</option>';
							foreach(BinContact::formLanguage() as $key => $value)
							{
								echo '<option value="'.$key.'" '.selected(get_post_meta($post->ID, 'bin_contact_language_of_correspondence', true), $key, false).'>'.BinContact::formLanguageValue()[$value].'</option>';
							}
						echo '</select>';
					echo '</td>';
				echo '</tr>';
			echo '</tbody>';
		echo '</table>';
	}
	
	function bin_contact_metabox_contact_build($post)
	{
		echo '<table class="form-table">';
			echo '<tbody>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_email">'.BinContact::formTextLabels()['email'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_email" class="regular-text" type="text" name="bin_contact_email" value="'.get_post_meta($post->ID, 'bin_contact_email', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_email_status">'.BinContact::formTextLabels()['email_status'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<select id="bin_contact_email_status" class="regular-text" type="text" name="bin_contact_email_status">';
							echo '<option value="unconfirmed" '.selected(get_post_meta($post->ID, 'bin_contact_email_status', true), 'unconfirmed', false).'>'.__('Unconfirmed', 'bin-contact').'</option>';
							echo '<option value="confirmed" '.selected(get_post_meta($post->ID, 'bin_contact_email_status', true), 'confirmed', false).'>'.__('Confirmed', 'bin-contact').'</option>';
						echo '</select>';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_mobile">'.BinContact::formTextLabels()['mobile'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_mobile" class="regular-text" type="text" name="bin_contact_mobile" value="'.get_post_meta($post->ID, 'bin_contact_mobile', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_mobile_status">'.BinContact::formTextLabels()['mobile_status'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<select id="bin_contact_mobile_status" class="regular-text" type="text" name="bin_contact_mobile_status">';
							echo '<option value="unconfirmed" '.selected(get_post_meta($post->ID, 'bin_contact_mobile_status', true), 'unconfirmed', false).'>'.__('Unconfirmed', 'bin-contact').'</option>';
							echo '<option value="confirmed" '.selected(get_post_meta($post->ID, 'bin_contact_mobile_status', true), 'confirmed', false).'>'.__('Confirmed', 'bin-contact').'</option>';
						echo '</select>';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_phone_private">'.BinContact::formTextLabels()['phone_private'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_phone_private" class="regular-text" type="text" name="bin_contact_phone_private" value="'.get_post_meta($post->ID, 'bin_contact_phone_private', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_phone_work">'.BinContact::formTextLabels()['phone_work'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_phone_work" class="regular-text" type="text" name="bin_contact_phone_work" value="'.get_post_meta($post->ID, 'bin_contact_phone_work', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_additional_designation">'.BinContact::formTextLabels()['additional_designation'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_additional_designation" class="regular-text" type="text" name="bin_contact_additional_designation" value="'.get_post_meta($post->ID, 'bin_contact_additional_designation', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_street_and_number">'.BinContact::formTextLabels()['street_and_number'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_street_and_number" class="regular-text" type="text" name="bin_contact_street_and_number" value="'.get_post_meta($post->ID, 'bin_contact_street_and_number', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_zip">'.BinContact::formTextLabels()['zip'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_zip" class="regular-text" type="text" name="bin_contact_zip" value="'.get_post_meta($post->ID, 'bin_contact_zip', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_city">'.BinContact::formTextLabels()['city'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_city" class="regular-text" type="text" name="bin_contact_city" value="'.get_post_meta($post->ID, 'bin_contact_city', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_country">'.BinContact::formTextLabels()['country'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<select id="bin_contact_country" class="regular-text" type="text" name="bin_contact_country">';
						
							echo '<option value="" '.selected(get_post_meta($post->ID, 'bin_contact_country', true), '', false).'>'.__('-- empty --', 'bin-contact').'</option>';
							foreach(BinContact::formCounty() as $key => $value)
							{
								echo '<option value="'.$key.'" '.selected(get_post_meta($post->ID, 'bin_contact_country', true), $key, false).'>'.BinContact::formCountyValue()[$value].'</option>';
							}
						echo '</select>';
					echo '</td>';
				echo '</tr>';
			echo '</tbody>';
		echo '</table>';
	}
	
	function bin_contact_metabox_legal_build($post)
	{
		echo '<table class="form-table">';
			echo '<tbody>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_terms_and_conditions_accepted">'.BinContact::formTextLabels()['terms_and_conditions_accepted'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<select id="bin_contact_terms_and_conditions_accepted" class="regular-text" type="text" name="bin_contact_terms_and_conditions_accepted">';
							echo '<option value="" '.selected(get_post_meta($post->ID, 'bin_contact_terms_and_conditions_accepted', true), '', false).'>'.__('-- empty --', 'bin-contact').'</option>';
							echo '<option value="no" '.selected(get_post_meta($post->ID, 'bin_contact_terms_and_conditions_accepted', true), 'no', false).'>'.__('No', 'bin-contact').'</option>';
							echo '<option value="yes" '.selected(get_post_meta($post->ID, 'bin_contact_terms_and_conditions_accepted', true), 'yes', false).'>'.__('Yes', 'bin-contact').'</option>';
						echo '</select>';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_privacy_policy_accepted">'.BinContact::formTextLabels()['privacy_policy_accepted'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<select id="bin_contact_privacy_policy_accepted" class="regular-text" type="text" name="bin_contact_privacy_policy_accepted">';
							echo '<option value="" '.selected(get_post_meta($post->ID, 'bin_contact_privacy_policy_accepted', true), '', false).'>'.__('-- empty --', 'bin-contact').'</option>';
							echo '<option value="no" '.selected(get_post_meta($post->ID, 'bin_contact_privacy_policy_accepted', true), 'no', false).'>'.__('No', 'bin-contact').'</option>';
							echo '<option value="yes" '.selected(get_post_meta($post->ID, 'bin_contact_privacy_policy_accepted', true), 'yes', false).'>'.__('Yes', 'bin-contact').'</option>';
						echo '</select>';
					echo '</td>';
				echo '</tr>';
			echo '</tbody>';
		echo '</table>';
	}
	
	function bin_contact_metabox_map_build($post)
	{
		echo '<div id="cwp-leaflet">';
			echo '<table class="form-table">';
				echo '<tbody>';
					echo '<tr>';
						echo '<th scope="row">';
							echo '<label for="bin_contact_marker_type">'.BinContact::formTextLabels()['marker_type'].'</label>';
						echo '</th>';
						echo '<td>';
							echo '<select id="bin_contact_marker_type" name="bin_contact_marker_type" class="components-select-control__input" data-bin-contact-condition="custom:js_bin_contact_condition_hidden_marker_type_custom">';
								echo '<option value="default" '.selected(get_post_meta($post->ID, 'bin_contact_marker_type', true), 'default', false).'>'.__('Default', 'bin-contact').'</option>';
								echo '<option value="custom" '.selected(get_post_meta($post->ID, 'bin_contact_marker_type', true), 'custom', false).'>'.__('Custom', 'bin-contact').'</option>';
							echo '</select>';
						echo '</td>';
					echo '</tr>';
					echo '<tr class="js_bin_contact_condition_hidden_marker_type_custom bin_contact_condition_hidden">';
						echo '<th>';
							echo '<label for="bin_contact_marker_custom">'.BinContact::formTextLabels()['marker_custom'].'</label>';
						echo '</th>';
						echo '<td>';
							echo '<div class="bin_contact_media_select">';
								echo '<div class="bin_contact_media_field">';
									echo '<input id="bin_contact_marker_custom" class="regular-text" type="url"  name="bin_contact_marker_custom" value="'.get_post_meta($post->ID, 'bin_contact_marker_custom', true).'">';
									echo '<a href="#" class="bin_contact_empty_field"><span class="dashicons dashicons-dismiss"></span></a>';
								echo '</div>';
								echo '<button type="button" class="button" data-media-uploader-target="#bin_contact_marker_custom">'.__('Upload Media', 'bin-contact').'</button>';
							echo '</div>';
						echo '</td>';
					echo '</tr>';
					echo '<tr class="js_bin_contact_condition_hidden_marker_type_custom bin_contact_condition_hidden">';
						echo '<th>';
							echo '<label for="bin_contact_marker_custom2x">'.BinContact::formTextLabels()['marker_custom2x'].'</label>';
						echo '</th>';
						echo '<td>';
							echo '<div class="bin_contact_media_select">';
								echo '<div class="bin_contact_media_field">';
									echo '<input id="bin_contact_marker_custom2x" class="regular-text" type="url"  name="bin_contact_marker_custom2x" value="'.get_post_meta($post->ID, 'bin_contact_marker_custom2x', true).'">';
									echo '<a href="#" class="bin_contact_empty_field"><span class="dashicons dashicons-dismiss"></span></a>';
								echo '</div>';
								echo '<button type="button" class="button" data-media-uploader-target="#bin_contact_marker_custom2x">'.__('Upload Media', 'bin-contact').'</button>';
							echo '</div>';
						echo '</td>';
					echo '</tr>';
					echo '<tr>';
						echo '<th scope="row">';
							echo '<label for="bin_contact_lat">'.BinContact::formTextLabels()['lat'].'</label>';
						echo '</th>';
						echo '<td>';
							echo '<input id="bin_contact_lat" class="regular-text" type="text" name="bin_contact_lat" value="'.get_post_meta($post->ID, 'bin_contact_lat', true).'">';
						echo '</td>';
					echo '</tr>';
					echo '<tr>';
						echo '<th scope="row">';
							echo '<label for="bin_contact_lng">'.BinContact::formTextLabels()['lng'].'</label>';
						echo '</th>';
						echo '<td>';
							echo '<input id="bin_contact_lng" class="regular-text" type="text" name="bin_contact_lng" value="'.get_post_meta($post->ID, 'bin_contact_lng', true).'">';
						echo '</td>';
					echo '</tr>';
				echo '</tbody>';
			echo '</table>';
		
			echo '<hr>';
			
			$searchArray = [];
			if(get_post_meta($post->ID, 'bin_contact_street_and_number', true)) { $searchArray[] = get_post_meta($post->ID, 'bin_contact_street_and_number', true); }
			if(get_post_meta($post->ID, 'bin_contact_city', true)) { $searchArray[] = get_post_meta($post->ID, 'bin_contact_city', true); }
			if(get_post_meta($post->ID, 'bin_contact_zip', true)) { $searchArray[] = get_post_meta($post->ID, 'bin_contact_zip', true); }			
			$searchString = implode(', ', $searchArray);
			
			echo '<div class="bin_contact_leaflet_search_wrapper">';
				echo '<p class="cwp-leaflet-search-title"><strong>'.__('Search for the location (latitude/longitude) via the address or select the location directly on the map.', 'bin-contact').'</strong></p>';
				echo '<div class="cwp-leaflet-search-inner">';
					echo '<input id="cwp-leaflet-address" type="text" placeholder="'.__('Search by Address', 'bin-contact').'" class="regular-text" value="'.$searchString.'">';
					echo '<button id="cwp-leaflet-search" type="button" class="button">'.__('Search', 'bin-contact').'</button>';
				echo '</div>';
				echo '<div class="cwp-leaflet-result"></div>';
			echo '</div>';
		
			echo '<div class="bin_contact_leaflet_map"></div>';
		echo '</div>';
	}
	
	function bin_contact_metabox_socialmedia_build($post)
	{
		echo '<table class="form-table">';
			echo '<tbody>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_website">'.BinContact::formTextLabels()['website'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_website" class="regular-text" type="text" name="bin_contact_website" value="'.get_post_meta($post->ID, 'bin_contact_website', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_facebook">'.BinContact::formTextLabels()['facebook'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_facebook" class="regular-text" type="text" name="bin_contact_facebook" value="'.get_post_meta($post->ID, 'bin_contact_facebook', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_twitter">'.BinContact::formTextLabels()['twitter'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_twitter" class="regular-text" type="text" name="bin_contact_twitter" value="'.get_post_meta($post->ID, 'bin_contact_twitter', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_instagram">'.BinContact::formTextLabels()['instagram'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_instagram" class="regular-text" type="text" name="bin_contact_instagram" value="'.get_post_meta($post->ID, 'bin_contact_instagram', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_flickr">'.BinContact::formTextLabels()['flickr'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_flickr" class="regular-text" type="text" name="bin_contact_flickr" value="'.get_post_meta($post->ID, 'bin_contact_flickr', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_linkedin">'.BinContact::formTextLabels()['linkedin'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_linkedin" class="regular-text" type="text" name="bin_contact_linkedin" value="'.get_post_meta($post->ID, 'bin_contact_linkedin', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_xing">'.BinContact::formTextLabels()['xing'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_xing" class="regular-text" type="text" name="bin_contact_xing" value="'.get_post_meta($post->ID, 'bin_contact_xing', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_youtube">'.BinContact::formTextLabels()['youtube'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_youtube" class="regular-text" type="text" name="bin_contact_youtube" value="'.get_post_meta($post->ID, 'bin_contact_youtube', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_socialmedia_other1">'.BinContact::formTextLabels()['socialmedia_other1'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_socialmedia_other1" class="regular-text" type="text" name="bin_contact_socialmedia_other1" value="'.get_post_meta($post->ID, 'bin_contact_socialmedia_other1', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_socialmedia_other2">'.BinContact::formTextLabels()['socialmedia_other2'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_socialmedia_other2" class="regular-text" type="text" name="bin_contact_socialmedia_other2" value="'.get_post_meta($post->ID, 'bin_contact_socialmedia_other2', true).'">';
					echo '</td>';
				echo '</tr>';
				echo '<tr>';
					echo '<th scope="row">';
						echo '<label for="bin_contact_socialmedia_other3">'.BinContact::formTextLabels()['socialmedia_other3'].'</label>';
					echo '</th>';
					echo '<td>';
						echo '<input id="bin_contact_socialmedia_other3" class="regular-text" type="text" name="bin_contact_socialmedia_other3" value="'.get_post_meta($post->ID, 'bin_contact_socialmedia_other3', true).'">';
					echo '</td>';
				echo '</tr>';
			echo '</tbody>';
		echo '</table>';
	}
	
	/**
	 * Store custom field meta box data
	 *
	 * @param int $post_id The post ID.
	 * @link https://codex.wordpress.org/Plugin_API/Action_Reference/save_post
	 */
	function save_post($post_id)
	{
		// verify meta box nonce
		if(!isset($_POST['bin_contact_meta_box_nonce']) || !wp_verify_nonce($_POST['bin_contact_meta_box_nonce'], basename( __FILE__ ))) { return; }

		// return if autosave
		if(defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) { return; }

		// Check the user's permissions.
		if(!current_user_can('edit_post', $post_id)) { return; }
		
		// store custom fields values
		if(isset($_POST['bin_contact_image'])) { update_post_meta($post_id, 'bin_contact_image', sanitize_text_field($_POST['bin_contact_image'])); }
		if(isset($_POST['bin_contact_company'])) { update_post_meta($post_id, 'bin_contact_company', sanitize_text_field($_POST['bin_contact_company'])); }
		if(isset($_POST['bin_contact_salutation'])) { update_post_meta($post_id, 'bin_contact_salutation', sanitize_text_field($_POST['bin_contact_salutation'])); }
		if(isset($_POST['bin_contact_picked_up'])) { update_post_meta($post_id, 'bin_contact_picked_up', sanitize_text_field($_POST['bin_contact_picked_up'])); }
		if(isset($_POST['bin_contact_name_suffix'])) { update_post_meta($post_id, 'bin_contact_name_suffix', sanitize_text_field($_POST['bin_contact_name_suffix'])); }
		if(isset($_POST['bin_contact_first_name'])) { update_post_meta($post_id, 'bin_contact_first_name', sanitize_text_field($_POST['bin_contact_first_name'])); }
		if(isset($_POST['bin_contact_last_name'])) { update_post_meta($post_id, 'bin_contact_last_name', sanitize_text_field($_POST['bin_contact_last_name'])); }
		if(isset($_POST['bin_contact_designation'])) { update_post_meta($post_id, 'bin_contact_designation', sanitize_text_field($_POST['bin_contact_designation'])); }
		if(isset($_POST['bin_contact_polite_form'])) { update_post_meta($post_id, 'bin_contact_polite_form', sanitize_text_field($_POST['bin_contact_polite_form'])); }
		if(isset($_POST['bin_contact_language_of_correspondence'])) { update_post_meta($post_id, 'bin_contact_language_of_correspondence', sanitize_text_field($_POST['bin_contact_language_of_correspondence'])); }
		if(isset($_POST['bin_contact_email'])) { update_post_meta($post_id, 'bin_contact_email', sanitize_email($_POST['bin_contact_email'])); }
		if(isset($_POST['bin_contact_email_status'])) { update_post_meta($post_id, 'bin_contact_email_status', sanitize_text_field($_POST['bin_contact_email_status'])); }
		if(isset($_POST['bin_contact_mobile'])) { update_post_meta($post_id, 'bin_contact_mobile', sanitize_text_field($_POST['bin_contact_mobile'])); }
		if(isset($_POST['bin_contact_mobile_status'])) { update_post_meta($post_id, 'bin_contact_mobile_status', sanitize_text_field($_POST['bin_contact_mobile_status'])); }
		if(isset($_POST['bin_contact_phone_private'])) { update_post_meta($post_id, 'bin_contact_phone_private', sanitize_text_field($_POST['bin_contact_phone_private'])); }
		if(isset($_POST['bin_contact_phone_work'])) { update_post_meta($post_id, 'bin_contact_phone_work', sanitize_text_field($_POST['bin_contact_phone_work'])); }
		if(isset($_POST['bin_contact_additional_designation'])) { update_post_meta($post_id, 'bin_contact_additional_designation', sanitize_text_field($_POST['bin_contact_additional_designation'])); }
		if(isset($_POST['bin_contact_street_and_number'])) { update_post_meta($post_id, 'bin_contact_street_and_number', sanitize_text_field($_POST['bin_contact_street_and_number'])); }
		if(isset($_POST['bin_contact_zip'])) { update_post_meta($post_id, 'bin_contact_zip', sanitize_text_field($_POST['bin_contact_zip'])); }
		if(isset($_POST['bin_contact_city'])) { update_post_meta($post_id, 'bin_contact_city', sanitize_text_field($_POST['bin_contact_city'])); }
		if(isset($_POST['bin_contact_country'])) { update_post_meta($post_id, 'bin_contact_country', sanitize_text_field($_POST['bin_contact_country'])); }
		if(isset($_POST['bin_contact_website'])) { update_post_meta($post_id, 'bin_contact_website', sanitize_text_field($_POST['bin_contact_website'])); }
		if(isset($_POST['bin_contact_facebook'])) { update_post_meta($post_id, 'bin_contact_facebook', sanitize_text_field($_POST['bin_contact_facebook'])); }
		if(isset($_POST['bin_contact_twitter'])) { update_post_meta($post_id, 'bin_contact_twitter', sanitize_text_field($_POST['bin_contact_twitter'])); }
		if(isset($_POST['bin_contact_instagram'])) { update_post_meta($post_id, 'bin_contact_instagram', sanitize_text_field($_POST['bin_contact_instagram'])); }
		if(isset($_POST['bin_contact_flickr'])) { update_post_meta($post_id, 'bin_contact_flickr', sanitize_text_field($_POST['bin_contact_flickr'])); }
		if(isset($_POST['bin_contact_linkedin'])) { update_post_meta($post_id, 'bin_contact_linkedin', sanitize_text_field($_POST['bin_contact_linkedin'])); }
		if(isset($_POST['bin_contact_xing'])) { update_post_meta($post_id, 'bin_contact_xing', sanitize_text_field($_POST['bin_contact_xing'])); }
		if(isset($_POST['bin_contact_youtube'])) { update_post_meta($post_id, 'bin_contact_youtube', sanitize_text_field($_POST['bin_contact_youtube'])); }
		if(isset($_POST['bin_contact_socialmedia_other1'])) { update_post_meta($post_id, 'bin_contact_socialmedia_other1', sanitize_text_field($_POST['bin_contact_socialmedia_other1'])); }
		if(isset($_POST['bin_contact_socialmedia_other2'])) { update_post_meta($post_id, 'bin_contact_socialmedia_other2', sanitize_text_field($_POST['bin_contact_socialmedia_other2'])); }
		if(isset($_POST['bin_contact_socialmedia_other3'])) { update_post_meta($post_id, 'bin_contact_socialmedia_other3', sanitize_text_field($_POST['bin_contact_socialmedia_other3'])); }
		if(isset($_POST['bin_contact_committee'])) { update_post_meta($post_id, 'bin_contact_committee', sanitize_text_field($_POST['bin_contact_committee'])); }
		if(isset($_POST['bin_contact_petition'])) { update_post_meta($post_id, 'bin_contact_petition', sanitize_text_field($_POST['bin_contact_petition'])); }
		if(isset($_POST['bin_contact_marker_type'])) { update_post_meta($post_id, 'bin_contact_marker_type', sanitize_text_field($_POST['bin_contact_marker_type'])); }
		if(isset($_POST['bin_contact_marker_custom'])) { update_post_meta($post_id, 'bin_contact_marker_custom', sanitize_text_field($_POST['bin_contact_marker_custom'])); }
		if(isset($_POST['bin_contact_marker_custom2x'])) { update_post_meta($post_id, 'bin_contact_marker_custom2x', sanitize_text_field($_POST['bin_contact_marker_custom2x'])); }
		if(isset($_POST['bin_contact_lat'])) { update_post_meta($post_id, 'bin_contact_lat', sanitize_text_field($_POST['bin_contact_lat'])); }
		if(isset($_POST['bin_contact_lng'])) { update_post_meta($post_id, 'bin_contact_lng', sanitize_text_field($_POST['bin_contact_lng'])); }
		if(isset($_POST['bin_contact_terms_and_conditions_accepted'])) { update_post_meta($post_id, 'bin_contact_terms_and_conditions_accepted', sanitize_text_field($_POST['bin_contact_terms_and_conditions_accepted'])); }
		if(isset($_POST['bin_contact_privacy_policy_accepted'])) { update_post_meta($post_id, 'bin_contact_privacy_policy_accepted', sanitize_text_field($_POST['bin_contact_privacy_policy_accepted'])); }
	}
}
